---
title: '비인증결제(정기,수기)지원 결제대행사 '
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 정기결제
searchTags:
  - 비인증 결제대행사
  - 정기결제
  - 수기
  - 정기
  - 비인증
datetime: 2025-02-19T05:32:46.707Z
---

<Callout content="비인증결제(정기,수기) 지원하는 결제대행사를 알려드립니다. " />

**나이스페이먼츠**

- 신용카드 정기결제(API)
- 신용카드 수기결제(API)

**NHN KCP** \
`중개플랫폼 형태서비스는 입점이 어렵습니다.`

- 신용카드 정기결제(결제창)
- 신용카드 정기결제(API)
- 신용카드 수기결제(결제창)
- 신용카드 수기결제(API)

**키움페이(다우데이타)**

- 신용카드 정기결제(API)
- 신용카드 수기결제(API)

**KSNET**\
`KSNET 결제창을 통한 방식지원 (간편결제 직접 호출 불가)`

- 신용카드 정기결제(API)
- 신용카드 수기결제(API)

**KG모빌리언스**

- 휴대폰 소액결제 정기결제(결제창)

**스마트로**

<Callout content="- 정기결제, 간편결제(허브형)은 신 스마트로에서만 지원가능 
- 스마트로-정기결제(카드-API) , 수기결제(가상계좌-API) 방식은 포트원 결제모듈 v2에서만 지원합니다 
- 스마트로-정기결제(API)는 스마트로 내부 정책이 강화되어, 신규서비스는 이용이 불가 합니다. 
(결제창 방식만 이용가능) 2024.12" />

- 신용카드 정기결제(결제창)
- 신용카드 정기결제(API)
- 신용카드 수기결제(API)

**헥토파이낸셜(세틀뱅크)**

- 신용카드 정기결제(API)
- 신용카드 수기결제(API)

**KG이니시스**\
`KG이니시스 정기결제는 PC환경에서 공인인증 절차가 필요합니다(모바일환경은 인증절차 없음)`

- 신용카드 정기결제(결제창)

**KICC(한국정보통신)**

- 신용카드 정기결제(결제창)

**다날**\
`다날 결제창을 통한 방식지원 (간편결제 직접 호출 불가)`

- 신용카드 정기결제(결제창)
- 신용카드 수기결제(결제창)
- 휴대폰 소액결제 정기결제(결제창)

**토스페이먼츠**\
`정기결제는 신모듈로만 지원가능`

- 신용카드 정기결제(결제창)
- 신용카드 정기결제(API)
- 신용카드 수기결제(API)
- 신용카드 수기결제(결제창)

**웰컴페이먼츠**

- 신용카드 정기결제(결제창)
- 신용카드 정기결제(API)
- 신용카드 수기결제(API)
- 휴대폰 소액결제 정기결제(결제창)

**한국결제네트웍스(KPN)**

- 신용카드 정기결제(API)
- 신용카드 수기결제(API)
- 신용카드 정기결제(결제창)

**네이버페이 결제형**

- 신용카드 정기결제(결제창)

<Indent level="1">

- 간편결제 일반결제 : 신용카드, 실시간 계좌이체, 네이버 포인트 \* 간편결제
  정기결제 : 신용카드, 네이버 포인트

</Indent>

**카카오페이**

- 신용카드 정기결제(결제창)

<Indent level="1">

- 간편결제 일반결제 : 신용카드, 카카오머니 \* 간편결제 정기결제 : 신용카드,
  카카오머니

</Indent>

**페이코**

- 신용카드 정기결제(결제창)

<Indent level="1">

- 간편결제 일반결제 : 신용카드, 페이코 포인트, 페이코 쿠폰 \* 간편결제 정기결제
  : 신용카드, 페이코 포인트

</Indent>

**페이먼트월(해외결제)**

- 신용카드 정기결제(결제창)

<Indent level="1">

- 해외결제 일반결제 : 해외카드(비자,마스터,JCB,Amex) , 위챗, 알리페이,
  유니온페이, 텐페이, YandexMoney, Molpay, eContext

</Indent>

**페이팔(해외결제)**

- 신용카드 정기결제(결제창)
